==> rags2ridges_2.0.tar.gz: rags2ridges/R/rags2ridgesMisc.R <==
################################################################################
################################################################################
##------------------------------------------------------------------------------
##
## Module C: rags2ridges Miscellaneous
##
##------------------------------------------------------------------------------
################################################################################
################################################################################


.TwoCents <- function(){
  ##############################################################################
  # - Unsolicited Advice
  ##############################################################################

  cat("
      ##########################
      ##########################
      Get ridge or die trying.
      - 2Cents
      ##########################
      ########################## \n")
}



.Brooke <- function(){
  ##############################################################################
  # - Endorsement
  ##############################################################################

  cat("
      ##############################################
      ##############################################
      To be Bold & Beautiful, one has to go Ridge.
      - Brooke Logan
      ##############################################
      ############################################## \n")
}



.JayZScore <- function() {
  ##############################################################################
  # - The truth
  ##############################################################################

  cat("
      ###################################################
      ###################################################
      I'm from rags to ridges baby I ain't dumb
      I got 99 problems but the ridge ain't one.
      - Jay Z-score
      ###################################################
      ################################################### \n")
}



.theHoff <- function() {
  ##############################################################################
  # - Shoulda coulda woulda
  ##############################################################################

  cat("
      ###################################################
      ###################################################
      If only KITT would have had this software...
      - Michael Knight
      ###################################################
      ################################################### \n")
}



.rags2logo <- function(){
  ##############################################################################
  # - Logo
  ##############################################################################

  cat("
     ____      _____  ______  ____    ____  ____  _____ ____________
    / __ \\/\\  / ____\\/ ____/ /___ \\  / __ \\/ /  \\/ ____\\ ____/ ____/
   / /_/ /  \\/ / __ / /___   ___/ / / /_/ / / /\\ \\/ __/ /___/ /___
  / _  _/ /\\ \\/ |_ |___  / / ____/ / _  _/ / / / / |_ |____/___  /
 / / \\ \\ ____ \\__/ /__/ / / /___  / / \\ \\ / /_/ /\\__/ /_______/ /
/_/   \\_\\    \\_\\__/____/ /_____/ /_/   \\_\\_____/\\____/___/_____/

")
}

==> rags2ridges_2.1.1.tar.gz: rags2ridges/R/rags2ridgesMisc.R <==
################################################################################
################################################################################
##------------------------------------------------------------------------------
##
## Module C: rags2ridges Miscellaneous
##
##------------------------------------------------------------------------------
################################################################################
################################################################################


.TwoCents <- function(){
  ##############################################################################
  # - Unsolicited Advice
  ##############################################################################

  cat("
      ##########################
      ##########################
      Get ridge or die trying.
      - 2Cents
      ##########################
      ########################## \n")
}



.Brooke <- function(){
  ##############################################################################
  # - Endorsement
  ##############################################################################

  cat("
      ##############################################
      ##############################################
      To be Bold & Beautiful, one has to go Ridge.
      - Brooke Logan
      ##############################################
      ############################################## \n")
}



.JayZScore <- function() {
  ##############################################################################
  # - The truth
  ##############################################################################

  cat("
      ###################################################
      ###################################################
      I'm from rags to ridges baby I ain't dumb
      I got 99 problems but the ridge ain't one.
      - Jay Z-score
      ###################################################
      ################################################### \n")
}



.theHoff <- function() {
  ##############################################################################
  # - Shoulda coulda woulda
  ##############################################################################

  cat("
      ###################################################
      ###################################################
      This has put the 'IT' in KITT.
      - Michael Knight
      ###################################################
      ################################################### \n")
}



.Marty <- function() {
  ##############################################################################
  # - Relief
  ##############################################################################

  cat("
      ###################################################
      ###################################################
      Finally, forward to the future!
      - Marty McFly
      ###################################################
      ################################################### \n")
}



.Boyka <- function() {
  ##############################################################################
  # - Completeness
  ##############################################################################

  cat("
      ###################################################
      ###################################################
      This is the most complete package in the world!
      - Yuri Boyka
      ###################################################
      ################################################### \n")
}



.Rich <- function() {
  ##############################################################################
  # - He's the one to know
  ##############################################################################

  cat("
      ###################################################
      ###################################################
      This is my favorite natural ridge package!
      No order 66 on this one, right babe?
      - Rich Piano
      ###################################################
      ################################################### \n")
}



.Chance <- function() {
  ##############################################################################
  # - Botanical ridge
  ##############################################################################

  cat("
      ###################################################
      ###################################################
      ... all is well. And all will be well in the garden
      - Chauncey Gardiner
      ###################################################
      ################################################### \n")
}



.rags2logo <- function(){
  ##############################################################################
  # - Logo
  ##############################################################################

  cat("
     ____      _____  ______  ____    ____  ____  _____ ____________
    / __ \\/\\  / ____\\/ ____/ /___ \\  / __ \\/ /  \\/ ____\\ ____/ ____/
   / /_/ /  \\/ / __ / /___   ___/ / / /_/ / / /\\ \\/ __/ /___/ /___
  / _  _/ /\\ \\/ |_ |___  / / ____/ / _  _/ / / / / |_ |____/___  /
 / / \\ \\ ____ \\__/ /__/ / / /___  / / \\ \\ / /_/ /\\__/ /_______/ /
/_/   \\_\\    \\_\\__/____/ /_____/ /_/   \\_\\_____/\\____/___/_____/

")
}
